"""Executor lifecycle endpoints: start/stop."""

from typing import Any

from fastapi import APIRouter

router = APIRouter(prefix="/queue", tags=["tools"])


@router.post("/start")
async def start_executor() -> dict[str, Any]:
    """Start the background executor loop."""
    from proxym.tools.executor import ToolExecutor
    await ToolExecutor.get().start()
    return {"ok": True, "message": "Executor started"}


@router.post("/stop")
async def stop_executor() -> dict[str, Any]:
    """Stop the background executor loop."""
    from proxym.tools.executor import ToolExecutor
    await ToolExecutor.get().stop()
    return {"ok": True, "message": "Executor stopped"}



"""Shared helpers for CLI command groups."""
from __future__ import annotations

import click


def make_args(ctx: click.Context, **kwargs):
    """Convert Click context to SimpleNamespace for legacy CLI handlers."""
    from proxym.ctl import _make_args as _ma
    return _ma(ctx, **kwargs)
